Download
Download
GetExportThumbnail
Returns export's thumbnail
Request
GET /download/e/{id}/thumbnail
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified thumbnail was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Specified thumbnail was not found or user do not has access to it |
GetExport
Returns a export file with specified id
Request
GET /download/e/{id}[?preview]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | ||
| preview | boolean | False |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified file was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Specified file was not found or user do not has access to the file |
|
| 500 | Try again, if error still here - text our support |
GetExports
Returns a zip archive with selected ids
Request
GET /download/es/{archiveName}[?fileIds&folderIds]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| fileIds | string | ids separated with a ',' sign |
|
| folderIds | string | ids separated with a ',' sign |
|
| *archiveName | string | name of the created archive |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified files was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Specified files were not found or user do not has access to the file |
GetLastSVGExport
returns export, that was created from report with specified id. INTERNAL USAGE ONLY!
Request
GET /download/lastPreview/{reportId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *reportId | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified file was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Specified file was not found or user do not has access to the file |
GetReportThumbnail
Returns report's thumbnail
Request
GET /download/r/{id}/thumbnail
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified thumbnail was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Specified thumbnail was not found or user do not has access to it |
GetReport
Returns a prepared file with specified id
Request
GET /download/r/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified file was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions |
|
| 404 | Specified file was not found or user do not has access to the file |
GetReports
Returns a zip archive with selected files
Request
GET /download/rs/{archiveName}[?fileIds&folderIds]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| fileIds | string | ids separated with a ',' sign |
|
| folderIds | string | ids separated with a ',' sign |
|
| *archiveName | string | name of the created archive |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Files were downloaded |
|
| 400 | Wrong parameters provided |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Files were not found |
GetTemplateThumbnail
Returns template's thumbnail
Request
GET /download/t/{id}/thumbnail
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified thumbnail was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions for the operation |
|
| 404 | Specified thumbnail was not found or user do not has access to it |
GetTemplate
Returns a Template file with specified id
Request
GET /download/t/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | template id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Specified file was found |
|
| 400 | Bad id provided |
|
| 402 | Subscription is blocked |
|
| 403 | Not enough permissions |
|
| 404 | Specified file was not found or user do not has access to the file |
GetTemplates
Returns a zip archive with selected files
Request
GET /download/ts/{archiveName}[?fileIds&folderIds]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| fileIds | string | ids separated with a ',' sign |
|
| folderIds | string | ids separated with a ',' sign |
|
| *archiveName | string | name of the created archive |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Files were downloaded |
|
| 400 | Wrong parameters provided |
|
| 402 | Subscription is blocked |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Files were not found |
Definitions
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |